@@ -6,14 +6,16 @@ from texbld.utils.github import get_github_rev
 
 def getsha256(resource):
     if mch := ImageResource.github_regex.fullmatch(resource):
-        owner, repository, rev = mch.groups()
+        # we don't care about the config file here.
+        owner, repository, rev, _ = mch.groups()
         rev = rev[1:] if rev is not None and len(rev) > 1 else None
         rev = get_github_rev(owner, repository, rev)
         image = GitHubImage(owner, repository, rev, sha256=None)
         image.client.fetch()
         return (rev, image.client.getsha256())
     else:
-        raise ArgumentTypeError(f'Error: Resource {resource} is not a GitHub resource.')
+        raise ArgumentTypeError(
+            f'Error: Resource {resource} is not a GitHub resource.')
 
 
 def getsha256_cli(args):
@@ -23,5 +25,6 @@ def getsha256_cli(args):
 
 
 def add_sha_args(parser: ArgumentParser):
-    parser.add_argument('resource', type=image_resource_type, help='GitHub resource to get sha256 of')
+    parser.add_argument('resource', type=image_resource_type,
+                        help='GitHub resource to get sha256 of')
     parser.set_defaults(func=getsha256_cli)
