@@ -6,6 +6,9 @@ CONFIG_BASE = os.path.join(Path.home(), ".config", "texbld")
 CACHE_BASE = os.path.join(Path.home(), ".cache", "texbld")
 SCAFFOLD_TESTS = ""
 
+# check if the cache is defined.
+if cache_environ := os.environ.get("TEXBLD_CACHE"):
+    CACHE_BASE = os.path.abspath(cache_environ)
 
 if "pytest" in sys.modules:
     dirname = os.path.join(os.path.dirname(
@@ -15,12 +18,18 @@ if "pytest" in sys.modules:
     SCAFFOLD_TESTS = os.path.join(dirname, "cache", "scaffold")
     os.makedirs(SCAFFOLD_TESTS, exist_ok=True)
 
+
 CONFIG_DIR = CONFIG_BASE
-LOCALPACKAGES_DIR = os.path.join(CONFIG_BASE, "packages")
 TARBALL_CACHE_DIR = os.path.join(CACHE_BASE, "tarballs")
 PACKAGE_CACHE_DIR = os.path.join(CACHE_BASE, "packages")
 BUILD_CACHE_DIR = os.path.join(CACHE_BASE, "builds")
 
+# check if the texbld package directory is defined.
+if texbld_packages := os.environ.get("TEXBLD_PACKAGES"):
+    LOCALPACKAGES_DIR = os.path.abspath(texbld_packages)
+else:
+    LOCALPACKAGES_DIR = os.path.join(CONFIG_BASE, "packages")
+
 dirs = [
     CONFIG_DIR, LOCALPACKAGES_DIR, TARBALL_CACHE_DIR, PACKAGE_CACHE_DIR, BUILD_CACHE_DIR
 ]
