@@ -1,7 +1,6 @@
-from texbld.docker.client import dockerclient
-
 from typing import TYPE_CHECKING
 import texbld.logger as logger
+import sys
 
 if TYPE_CHECKING:
     from texbld.common.image import Image
@@ -9,12 +8,16 @@ if TYPE_CHECKING:
 
 
 def build_image(image: 'Image', cache=False):
+    from texbld.docker.client import dockerclient
+
     logger.progress(f"Copying {image.docker_image_name()}...")
     image.copy_to_builds(cache=cache)
     logger.done(f"Copied {image.docker_image_name()}")
     logger.progress(f"Building {image.docker_image_name()}...")
-    dockerclient.images.build(path=image.build_dir(),
-                              tag=image.docker_image_name(), quiet=False)
+    generator = dockerclient.api.build(path=image.build_dir(), tag=image.docker_image_name(), decode=True)
+    for line in generator:
+        if x := line.get('stream'):
+            sys.stdout.write(x)
     logger.done(f"Finished building {image.docker_image_name()}")
 
 
